diff --git a/doc/src/sgml/libpq.sgml b/doc/src/sgml/libpq.sgml
index df0ad527ae42e20b78869451ebcb65761d6221ba..3fb6a4a85afbb2620bdc98ee1f2e6f01dfa46713 100644
--- a/doc/src/sgml/libpq.sgml
+++ b/doc/src/sgml/libpq.sgml
@@ -1,5 +1,5 @@
 <!--
-$PostgreSQL: pgsql/doc/src/sgml/libpq.sgml,v 1.200 2005/12/23 01:16:37 tgl Exp $
+$PostgreSQL: pgsql/doc/src/sgml/libpq.sgml,v 1.201 2005/12/26 14:58:04 petere Exp $
 -->
 
  <chapter id="libpq">
@@ -3574,14 +3574,14 @@ As always, there are some functions that just don't fit anywhere.
 
 <variablelist>
 <varlistentry>
-<term><function>pg_make_encrypted_password</function><indexterm><primary>pg_make_encrypted_password</></></term>
+<term><function>PQencryptPassword</function><indexterm><primary>PQencryptPassword</></></term>
 <listitem>
 <para>
 Prepares the encrypted form of a <productname>PostgreSQL</> password.
 <synopsis>
-char *pg_make_encrypted_password(const char *passwd, const char *user);
+char * PQencryptPassword(const char *passwd, const char *user);
 </synopsis>
-<function>pg_make_encrypted_password</> is intended to be used by client
+This function is intended to be used by client
 applications that wish to send commands like
 <literal>ALTER USER joe PASSWORD 'pwd'</>.
 It is good practice not to send the original cleartext password in such a
@@ -3589,7 +3589,7 @@ command, because it might be exposed in command logs, activity displays,
 and so on.  Instead, use this function to convert the password to encrypted
 form before it is sent.  The arguments are the cleartext password, and the SQL
 name of the user it is for.  The return value is a malloc'd string, or NULL if
-out-of-memory.  The caller may assume the string doesn't contain any weird
+out-of-memory.  The caller may assume the string doesn't contain any special
 characters that would require escaping.  Use <function>PQfreemem</> to free
 the result when done with it.
 </para>
diff --git a/src/bin/psql/command.c b/src/bin/psql/command.c
index 6e5ddf53696d7204512ba194975e7ad151d76631..e108ef20c2b52a511569aa4f6b91d1ea0004cd7f 100644
--- a/src/bin/psql/command.c
+++ b/src/bin/psql/command.c
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2000-2005, PostgreSQL Global Development Group
  *
- * $PostgreSQL: pgsql/src/bin/psql/command.c,v 1.157 2005/12/23 01:16:38 tgl Exp $
+ * $PostgreSQL: pgsql/src/bin/psql/command.c,v 1.158 2005/12/26 14:58:04 petere Exp $
  */
 #include "postgres_fe.h"
 #include "command.h"
@@ -643,7 +643,7 @@ exec_command(const char *cmd,
 			else
 				user = PQuser(pset.db);
 
-			encrypted_password = pg_make_encrypted_password(pw1, user);
+			encrypted_password = PQencryptPassword(pw1, user);
 
 			if (!encrypted_password)
 			{
diff --git a/src/bin/scripts/createuser.c b/src/bin/scripts/createuser.c
index 9bd7d8d873c3f18fe9f6f990176669629a330e56..03896583d3e7f45f815396dd4e822b7d443e7bd9 100644
--- a/src/bin/scripts/createuser.c
+++ b/src/bin/scripts/createuser.c
@@ -5,7 +5,7 @@
  * Portions Copyright (c) 1996-2005, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $PostgreSQL: pgsql/src/bin/scripts/createuser.c,v 1.25 2005/12/23 01:16:38 tgl Exp $
+ * $PostgreSQL: pgsql/src/bin/scripts/createuser.c,v 1.26 2005/12/26 14:58:05 petere Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -251,7 +251,7 @@ main(int argc, char *argv[])
 		{
 			char	   *encrypted_password;
 
-			encrypted_password = pg_make_encrypted_password(newpassword,
+			encrypted_password = PQencryptPassword(newpassword,
 															newuser);
 			if (!encrypted_password)
 			{
diff --git a/src/interfaces/libpq/exports.txt b/src/interfaces/libpq/exports.txt
index 3b95bccb467e6fe8b2f9d35a7ca1761f8221dd63..9cf43cfc245eefad63563b6c4b695e17faa77ff8 100644
--- a/src/interfaces/libpq/exports.txt
+++ b/src/interfaces/libpq/exports.txt
@@ -1,4 +1,4 @@
-# $PostgreSQL: pgsql/src/interfaces/libpq/exports.txt,v 1.6 2005/12/23 01:16:38 tgl Exp $
+# $PostgreSQL: pgsql/src/interfaces/libpq/exports.txt,v 1.7 2005/12/26 14:58:05 petere Exp $
 # Functions to be exported by libpq DLLs
 PQconnectdb               1
 PQsetdbLogin              2
@@ -125,4 +125,4 @@ PQcancel                  122
 lo_create                 123
 PQinitSSL                 124
 PQregisterThreadLock      125
-pg_make_encrypted_password 126
+PQencryptPassword         126
diff --git a/src/interfaces/libpq/libpq-fe.h b/src/interfaces/libpq/libpq-fe.h
index fc42c2b28a783617a789857ccae5b96af1c0eedc..edb2ee38c753c299a3220b389fc9e60d67894ff6 100644
--- a/src/interfaces/libpq/libpq-fe.h
+++ b/src/interfaces/libpq/libpq-fe.h
@@ -7,7 +7,7 @@
  * Portions Copyright (c) 1996-2005, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $PostgreSQL: pgsql/src/interfaces/libpq/libpq-fe.h,v 1.123 2005/12/23 01:16:38 tgl Exp $
+ * $PostgreSQL: pgsql/src/interfaces/libpq/libpq-fe.h,v 1.124 2005/12/26 14:58:06 petere Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -497,7 +497,7 @@ extern int	PQenv2encoding(void);
 
 /* === in fe-auth.c === */
 
-extern char *pg_make_encrypted_password(const char *passwd, const char *user);
+extern char *PQencryptPassword(const char *passwd, const char *user);
 
 #ifdef __cplusplus
 }
diff --git a/src/interfaces/libpq/fe-auth.c b/src/interfaces/libpq/fe-auth.c
index 039964a9fe5a2bbf2fab56d91867cdec643e741b..2f80b43dbbd393ab152aa06dee1a51d32d9fc5d8 100644
--- a/src/interfaces/libpq/fe-auth.c
+++ b/src/interfaces/libpq/fe-auth.c
@@ -10,7 +10,7 @@
  * exceed INITIAL_EXPBUFFER_SIZE (currently 256 bytes).
  *
  * IDENTIFICATION
- *	  $PostgreSQL: pgsql/src/interfaces/libpq/fe-auth.c,v 1.109 2005/12/23 01:16:38 tgl Exp $
+ *	  $PostgreSQL: pgsql/src/interfaces/libpq/fe-auth.c,v 1.110 2005/12/26 14:58:05 petere Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -534,7 +534,7 @@ pg_fe_getauthname(char *PQerrormsg)
 
 
 /*
  * pg_make_encrypted_password -- exported routine to encrypt a password
  *
  * This is intended to be used by client applications that wish to send
  * commands like ALTER USER joe PASSWORD 'pwd'.  The password need not
@@ -548,11 +548,11 @@ pg_fe_getauthname(char *PQerrormsg)
  * is for.
  *
  * Return value is a malloc'd string, or NULL if out-of-memory.  The client
- * may assume the string doesn't contain any weird characters that would
+ * may assume the string doesn't contain any special characters that would
  * require escaping.
  */
 char *
-pg_make_encrypted_password(const char *passwd, const char *user)
+PQencryptPassword(const char *passwd, const char *user)
 {
 	char	   *crypt_pwd;
 
@@ -534,7 +534,7 @@ pg_fe_getauthname(char *PQerrormsg)
 
 /*
- * pg_make_encrypted_password -- exported routine to encrypt a password
+ * PQencryptPassword -- exported routine to encrypt a password
  *
  * This is intended to be used by client applications that wish to send